summaryrefslogtreecommitdiff
path: root/kde-frameworks/krunner/files/krunner-5.92.0-increase-runnermanagertest-timeout.patch
blob: 7a586598c15ec624c1f5208429f1d3a4186d095d (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
From c1f589a7cda3a5d47479ab1188716df533ceb8b1 Mon Sep 17 00:00:00 2001
From: David Faure <faure@kde.org>
Date: Sun, 13 Mar 2022 13:08:26 +0100
Subject: [PATCH] autotests: urgh, this test is really timing dependent, and
 fails if CI is slow

---
 autotests/runnermanagertest.cpp | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/autotests/runnermanagertest.cpp b/autotests/runnermanagertest.cpp
index b9ccbc5..02c0985 100644
--- a/autotests/runnermanagertest.cpp
+++ b/autotests/runnermanagertest.cpp
@@ -84,7 +84,7 @@ private Q_SLOTS:
         QCOMPARE(spyQueryFinished.count(), 1); // Still the same, query is not done
 
         // We programmed it to emit the result after 300ms, so we need to wait 50ms more for the next emission
-        QVERIFY(spyQueryFinished.wait(65)); // 65ms as a margin of safety for 50ms
+        QVERIFY(spyQueryFinished.wait(100)); // 100ms as a margin of safety for 50ms
 
         // This should have taken at least 300ms total, as we requested via the special query string
         QVERIFY(timer.elapsed() >= 300);
-- 
GitLab